
From: Andrey Panin <pazke@donpac.ru>


Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c |   28 ++++++++++++++++++++-
 25-akpm/arch/i386/kernel/dmi_scan.c                |   20 ---------------
 2 files changed, 27 insertions(+), 21 deletions(-)

diff -puN arch/i386/kernel/cpu/cpufreq/powernow-k7.c~dmi-port-powernow-k7-driver-to-new-dmi-probing arch/i386/kernel/cpu/cpufreq/powernow-k7.c
--- 25/arch/i386/kernel/cpu/cpufreq/powernow-k7.c~dmi-port-powernow-k7-driver-to-new-dmi-probing	Fri May 28 14:28:53 2004
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c	Fri May 28 14:28:53 2004
@@ -22,6 +22,7 @@
 #include <linux/cpufreq.h>
 #include <linux/slab.h>
 #include <linux/string.h>
+#include <linux/dmi.h>
 
 #include <asm/msr.h>
 #include <asm/timex.h>
@@ -554,6 +555,31 @@ static unsigned int powernow_get(unsigne
 }
 
 
+static int __init acer_cpufreq_pst(struct dmi_system_id *d)
+{
+	printk(KERN_WARNING "%s laptop with broken PST tables in BIOS detected.\n", d->ident);
+	printk(KERN_WARNING "You need to downgrade to 3A21 (09/09/2002), or try a newer BIOS than 3A71 (01/20/2003)\n");
+	printk(KERN_WARNING "cpufreq scaling has been disabled as a result of this.\n");
+	return 0;
+}
+
+/*
+ * Some Athlon laptops have really fucked PST tables.
+ * A BIOS update is all that can save them.
+ * Mention this, and disable cpufreq.
+ */
+static struct dmi_system_id __initdata powernow_dmi_table[] = {
+	{
+		.callback = acer_cpufreq_pst,
+		.ident = "Acer Aspire",
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR, "Insyde Software"),
+			DMI_MATCH(DMI_BIOS_VERSION, "3A71"),
+		},
+	},
+	{ }
+};
+
 static int __init powernow_cpu_init (struct cpufreq_policy *policy)
 {
 	union msr_fidvidstatus fidvidstatus;
@@ -572,7 +598,7 @@ static int __init powernow_cpu_init (str
 	}
 	dprintk(KERN_INFO PFX "FSB: %3d.%03d MHz\n", fsb/1000, fsb%1000);
 
-	if ((dmi_broken & BROKEN_CPUFREQ) || acpi_force) {
+	if (dmi_check_system(powernow_dmi_table) || acpi_force) {
 		printk (KERN_INFO PFX "PSB/PST known to be broken.  Trying ACPI instead\n");
 		result = powernow_acpi_init();
 	} else {
diff -puN arch/i386/kernel/dmi_scan.c~dmi-port-powernow-k7-driver-to-new-dmi-probing arch/i386/kernel/dmi_scan.c
--- 25/arch/i386/kernel/dmi_scan.c~dmi-port-powernow-k7-driver-to-new-dmi-probing	Fri May 28 14:28:53 2004
+++ 25-akpm/arch/i386/kernel/dmi_scan.c	Fri May 28 14:28:53 2004
@@ -235,16 +235,6 @@ static __init int reset_videomode_after_
 #endif
 
 
-static __init int acer_cpufreq_pst(struct dmi_system_id *d)
-{
-	printk(KERN_WARNING "%s laptop with broken PST tables in BIOS detected.\n", d->ident);
-	printk(KERN_WARNING "You need to downgrade to 3A21 (09/09/2002), or try a newer BIOS than 3A71 (01/20/2003)\n");
-	printk(KERN_WARNING "cpufreq scaling has been disabled as a result of this.\n");
-	dmi_broken |= BROKEN_CPUFREQ;
-	return 0;
-}
-
-
 #ifdef	CONFIG_ACPI_PCI
 static __init int disable_acpi_irq(struct dmi_system_id *d)
 { 
@@ -311,16 +301,6 @@ static __initdata struct dmi_system_id d
 			} },
 #endif
 
-	/*
-	 * Some Athlon laptops have really fucked PST tables.
-	 * A BIOS update is all that can save them.
-	 * Mention this, and disable cpufreq.
-	 */
-	{ acer_cpufreq_pst, "Acer Aspire", {
-			DMI_MATCH(DMI_SYS_VENDOR, "Insyde Software"),
-			DMI_MATCH(DMI_BIOS_VERSION, "3A71"),
-			} },
-
 #ifdef CONFIG_SERIO_I8042
 	{ set_8042_nomux, "Compaq Proliant 8500", {
 			DMI_MATCH(DMI_SYS_VENDOR, "Compaq"),
_
